"use strict";
const typescript_template_language_service_decorator_1 = require("typescript-template-language-service-decorator");
const type_checker_1 = require("./type-checker");
const language_service_1 = require("./language-service");
const substitutions_1 = require("./substitutions");
const virtual_service_host_1 = require("./virtual-service-host");
const configuration_1 = require("./configuration");
const logger_1 = require("./logger");
const pluginMarker = Symbol("__sqlTaggedTemplatePluginMarker__");
class SqlTaggedTemplatePlugin {
    constructor(typescript) {
        this.typescript = typescript;
    }
    create(info) {
        if (info.languageService[pluginMarker]) {
            // Already decorated
            return info.languageService;
        }
        const logger = new logger_1.default(info);
        this.config = new configuration_1.ParsedPluginConfiguration(info.project, logger);
        this.onConfigurationChanged(info.config);
        const virtualServiceHost = new virtual_service_host_1.default(this.typescript, { ...info.languageServiceHost.getCompilationSettings(), plugins: [] }, info.project.getCurrentDirectory());
        const diagnostics = new type_checker_1.TypeChecker(this.typescript, virtualServiceHost, () => info.languageService.getProgram().getTypeChecker());
        const sqlTemplateLanguageService = new language_service_1.default(logger, this.config, diagnostics);
        const templateSettings = {
            tags: ["sql"],
            enableForStringWithSubstitutions: true,
            getSubstitutions: substitutions_1.getSubstitutions
        };
        const languageService = typescript_template_language_service_decorator_1.decorateWithTemplateLanguageService(this.typescript, info.languageService, info.project, sqlTemplateLanguageService, templateSettings, { logger });
        languageService[pluginMarker] = true;
        return languageService;
    }
    onConfigurationChanged(config) {
        this.config.update(config);
    }
}
module.exports = (mod) => new SqlTaggedTemplatePlugin(mod.typescript);
//# sourceMappingURL=index.js.map